<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN" sourcelanguage="en">
<context>
    <name>ActionShowStashDelegate</name>
    <message>
        <source>Application tray</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ActionToggleCollapseDelegate</name>
    <message>
        <source>Collapse tray</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PanelTrayItem</name>
    <message>
        <source>Quick actions</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
